@@ -26,6 +26,29 @@ class EsClient(AbstractClient):
     _service = 'es'
 
 
+    def CreateIndex(self, request):
+        """创建索引
+
+        :param request: Request instance for CreateIndex.
+        :type request: :class:`tencentcloud.es.v20180416.models.CreateIndexRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.CreateIndexResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateIndex", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateIndexResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateInstance(self, request):
         """创建指定规格的ES集群实例
 
@@ -36,17 +59,58 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateInstance", params)
+            headers = request.headers
+            body = self.call("CreateInstance", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateLogstashInstance(self, request):
+        """用于创建Logstash实例
+
+        :param request: Request instance for CreateLogstashInstance.
+        :type request: :class:`tencentcloud.es.v20180416.models.CreateLogstashInstanceRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.CreateLogstashInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLogstashInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLogstashInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteIndex(self, request):
+        """删除索引
+
+        :param request: Request instance for DeleteIndex.
+        :type request: :class:`tencentcloud.es.v20180416.models.DeleteIndexRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DeleteIndexResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteIndex", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteIndexResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -64,17 +128,104 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteInstance", params)
+            headers = request.headers
+            body = self.call("DeleteInstance", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DeleteInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteLogstashInstance(self, request):
+        """用于删除Logstash实例
+
+        :param request: Request instance for DeleteLogstashInstance.
+        :type request: :class:`tencentcloud.es.v20180416.models.DeleteLogstashInstanceRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DeleteLogstashInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteLogstashInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteLogstashInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteLogstashPipelines(self, request):
+        """用于批量删除Logstash管道
+
+        :param request: Request instance for DeleteLogstashPipelines.
+        :type request: :class:`tencentcloud.es.v20180416.models.DeleteLogstashPipelinesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DeleteLogstashPipelinesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteLogstashPipelines", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteLogstashPipelinesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeIndexList(self, request):
+        """获取索引列表
+
+        :param request: Request instance for DescribeIndexList.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeIndexListRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeIndexListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIndexList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIndexListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeIndexMeta(self, request):
+        """获取索引元数据
+
+        :param request: Request instance for DescribeIndexMeta.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeIndexMetaRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeIndexMetaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIndexMeta", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIndexMetaResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -92,17 +243,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceLogs", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceLogs", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeInstanceLogsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeInstanceLogsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -120,17 +266,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceOperations", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceOperations", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeInstanceOperationsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeInstanceOperationsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -148,17 +289,104 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstances", params)
+            headers = request.headers
+            body = self.call("DescribeInstances", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeInstancesResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DescribeInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeLogstashInstanceLogs(self, request):
+        """查询用户该地域下符合条件的Logstash实例的日志
+
+        :param request: Request instance for DescribeLogstashInstanceLogs.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeLogstashInstanceLogsRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeLogstashInstanceLogsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLogstashInstanceLogs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLogstashInstanceLogsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeLogstashInstanceOperations(self, request):
+        """查询实例指定条件下的操作记录
+
+        :param request: Request instance for DescribeLogstashInstanceOperations.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeLogstashInstanceOperationsRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeLogstashInstanceOperationsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLogstashInstanceOperations", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLogstashInstanceOperationsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeLogstashInstances(self, request):
+        """查询用户该地域下符合条件的所有Logstash实例
+
+        :param request: Request instance for DescribeLogstashInstances.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeLogstashInstancesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeLogstashInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLogstashInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLogstashInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeLogstashPipelines(self, request):
+        """用于获取Logstash实例管道列表
+
+        :param request: Request instance for DescribeLogstashPipelines.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeLogstashPipelinesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeLogstashPipelinesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLogstashPipelines", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLogstashPipelinesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -176,17 +404,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeViews", params)
+            headers = request.headers
+            body = self.call("DescribeViews", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeViewsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeViewsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -204,17 +427,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DiagnoseInstance", params)
+            headers = request.headers
+            body = self.call("DiagnoseInstance", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DiagnoseInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DiagnoseInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -232,17 +450,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetRequestTargetNodeTypes", params)
+            headers = request.headers
+            body = self.call("GetRequestTargetNodeTypes", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetRequestTargetNodeTypesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.GetRequestTargetNodeTypesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -260,17 +473,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartInstance", params)
+            headers = request.headers
+            body = self.call("RestartInstance", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.RestartInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.RestartInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -288,17 +496,35 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartKibana", params)
+            headers = request.headers
+            body = self.call("RestartKibana", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.RestartKibanaResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.RestartKibanaResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RestartLogstashInstance(self, request):
+        """用于重启Logstash实例
+
+        :param request: Request instance for RestartLogstashInstance.
+        :type request: :class:`tencentcloud.es.v20180416.models.RestartLogstashInstanceRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.RestartLogstashInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestartLogstashInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestartLogstashInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -316,17 +542,81 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartNodes", params)
+            headers = request.headers
+            body = self.call("RestartNodes", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.RestartNodesResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.RestartNodesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def SaveAndDeployLogstashPipeline(self, request):
+        """用于下发并且部署管道
+
+        :param request: Request instance for SaveAndDeployLogstashPipeline.
+        :type request: :class:`tencentcloud.es.v20180416.models.SaveAndDeployLogstashPipelineRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.SaveAndDeployLogstashPipelineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SaveAndDeployLogstashPipeline", params, headers=headers)
+            response = json.loads(body)
+            model = models.SaveAndDeployLogstashPipelineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StartLogstashPipelines(self, request):
+        """用于启动Logstash管道
+
+        :param request: Request instance for StartLogstashPipelines.
+        :type request: :class:`tencentcloud.es.v20180416.models.StartLogstashPipelinesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.StartLogstashPipelinesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartLogstashPipelines", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartLogstashPipelinesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopLogstashPipelines(self, request):
+        """用于批量停止Logstash管道
+
+        :param request: Request instance for StopLogstashPipelines.
+        :type request: :class:`tencentcloud.es.v20180416.models.StopLogstashPipelinesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.StopLogstashPipelinesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopLogstashPipelines", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopLogstashPipelinesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -344,17 +634,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateDiagnoseSettings", params)
+            headers = request.headers
+            body = self.call("UpdateDiagnoseSettings", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateDiagnoseSettingsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UpdateDiagnoseSettingsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -372,17 +657,35 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateDictionaries", params)
+            headers = request.headers
+            body = self.call("UpdateDictionaries", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateDictionariesResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.UpdateDictionariesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateIndex(self, request):
+        """更新索引
+
+        :param request: Request instance for UpdateIndex.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateIndexRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateIndexResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateIndex", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateIndexResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -407,17 +710,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateInstance", params)
+            headers = request.headers
+            body = self.call("UpdateInstance", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UpdateInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -435,17 +733,63 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateJdk", params)
+            headers = request.headers
+            body = self.call("UpdateJdk", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateJdkResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.UpdateJdkResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateLogstashInstance(self, request):
+        """对集群进行节点规格变更，修改实例名称，修改配置，等操作。参数中InstanceId为必传参数，参数传递组合及含义如下：
+        - InstanceName：修改实例名称(仅用于标识实例)
+        - NodeNum: 修改实例节点数量（节点横向扩缩容，纵向扩缩容等）
+        - YMLConfig: 修改实例YML配置
+        - BindedES：修改绑定的ES集群配置
+        以上参数组合只能传递一种，多传或少传均会导致请求失败
+
+        :param request: Request instance for UpdateLogstashInstance.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateLogstashInstanceRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateLogstashInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateLogstashInstance", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateLogstashInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateLogstashPipelineDesc(self, request):
+        """用于更新管道描述信息
+
+        :param request: Request instance for UpdateLogstashPipelineDesc.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateLogstashPipelineDescRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateLogstashPipelineDescResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateLogstashPipelineDesc", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateLogstashPipelineDescResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -463,17 +807,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdatePlugins", params)
+            headers = request.headers
+            body = self.call("UpdatePlugins", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdatePluginsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UpdatePluginsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -491,17 +830,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateRequestTargetNodeTypes", params)
+            headers = request.headers
+            body = self.call("UpdateRequestTargetNodeTypes", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateRequestTargetNodeTypesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UpdateRequestTargetNodeTypesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -519,17 +853,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeInstance", params)
+            headers = request.headers
+            body = self.call("UpgradeInstance", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpgradeInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UpgradeInstanceResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -547,17 +876,12 @@ class EsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeLicense", params)
+            headers = request.headers
+            body = self.call("UpgradeLicense", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpgradeLicenseResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.UpgradeLicenseResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
